Index: sakura/makefile
===================================================================
--- sakura/makefile	(revision 1065)
+++ sakura/makefile	(working copy)
@@ -187,8 +187,8 @@
 	$(OBJDIR)\CPropComKeyword.obj \
 	$(OBJDIR)\CPropCommon.obj \
 	$(OBJDIR)\CPropComMacro.obj \
+	$(OBJDIR)\CPropComTab.obj \
 	$(OBJDIR)\CPropComToolbar.obj \
-	$(OBJDIR)\CPropComUrl.obj \
 	$(OBJDIR)\CPropComWin.obj \
 	$(OBJDIR)\CPropTypes.obj \
 	$(OBJDIR)\CPropTypesKeyHelp.obj \
Index: sakura/sakura.dsp
===================================================================
--- sakura/sakura.dsp	(revision 1065)
+++ sakura/sakura.dsp	(working copy)
@@ -513,11 +513,11 @@
 # End Source File
 # Begin Source File
 
-SOURCE=..\sakura_core\CPropComToolbar.cpp
+SOURCE=..\sakura_core\CPropComTab.cpp
 # End Source File
 # Begin Source File
 
-SOURCE=..\sakura_core\CPropComUrl.cpp
+SOURCE=..\sakura_core\CPropComToolbar.cpp
 # End Source File
 # Begin Source File
 
Index: sakura_core/CEditView_Command.cpp
===================================================================
--- sakura_core/CEditView_Command.cpp	(revision 1065)
+++ sakura_core/CEditView_Command.cpp	(working copy)
@@ -8345,7 +8345,11 @@
 {
 	/* •Â‚¶‚é */
 	// ƒ^ƒu‚Ü‚Æ‚ß•\Ž¦‚ÅŽcƒEƒBƒ“ƒhƒE‚ª‚PŒÂ‚Ì�ê�‡‚Í�u•Â‚¶‚Ä–³‘è�v	// 2006.10.21 ryoji
-	if( m_pShareData->m_Common.m_bDispTabWnd && !m_pShareData->m_Common.m_bDispTabWndMultiWin ){
+	//	Feb. 11, 2007 genta ƒIƒvƒVƒ‡ƒ“‚Å“®�ì‚ð‘I‚×‚é‚æ‚¤‚É
+	if( m_pShareData->m_Common.m_bDispTabWnd &&
+		!m_pShareData->m_Common.m_bDispTabWndMultiWin &&
+		m_pShareData->m_Common.m_bTab_RetainEmptyWin
+		){
 		if( 1 == CShareData::getInstance()->GetEditorWindowsNum() ){
 			Command_FILECLOSE();
 			return;
Index: sakura_core/CEditWnd.cpp
===================================================================
--- sakura_core/CEditWnd.cpp	(revision 1065)
+++ sakura_core/CEditWnd.cpp	(working copy)
@@ -1401,8 +1401,12 @@
 */
 	case WM_SYSCOMMAND:
 		// ƒ^ƒu‚Ü‚Æ‚ß•\Ž¦‚Ì�ê�‡‚Í�u‚·‚×‚Ä•Â‚¶‚é�v	// 2006.10.21 ryoji
+		//	Feb. 11, 2007 genta “®�ì‚ð‘I‚×‚é‚æ‚¤‚É(MDI•—‚Æ�]—ˆ“®�ì)
 		if( wParam == SC_CLOSE ){
-			if( m_pShareData->m_Common.m_bDispTabWnd && !m_pShareData->m_Common.m_bDispTabWndMultiWin ){
+			if( m_pShareData->m_Common.m_bDispTabWnd &&
+				!m_pShareData->m_Common.m_bDispTabWndMultiWin &&
+				!m_pShareData->m_Common.m_bTab_CloseOneWin
+				){
 				::PostMessage( m_hWnd, WM_COMMAND, MAKEWPARAM( F_WIN_CLOSEALL, 0 ), (LPARAM)NULL );
 				return 0L;
 			}
Index: sakura_core/CPropComEdit.cpp
===================================================================
--- sakura_core/CPropComEdit.cpp	(revision 1065)
+++ sakura_core/CPropComEdit.cpp	(working copy)
@@ -29,6 +29,8 @@
 	IDC_CHECK_DRAGDROP,					HIDC_CHECK_DRAGDROP,					//Drag&Drop•Ò�W‚·‚é
 	IDC_CHECK_DROPSOURCE,				HIDC_CHECK_DROPSOURCE,					//ƒhƒ�ƒbƒvŒ³‚É‚·‚é
 	IDC_CHECK_bNotOverWriteCRLF,		HIDC_CHECK_bNotOverWriteCRLF,			//�ã�‘‚«ƒ‚�[ƒh
+	//	2007.02.11 genta ƒNƒŠƒbƒJƒuƒ‹URL‚ð‚±‚Ìƒy�[ƒW‚ÉˆÚ“®
+	IDC_CHECK_bSelectClickedURL,	HIDC_CHECK_bSelectClickedURL,	//ƒNƒŠƒbƒJƒuƒ‹URL
 //	IDC_STATIC,							-1,
 	0, 0
 };
@@ -196,6 +198,9 @@
 
 	/* ‰ü�s‚Í�ã�‘‚«‚µ‚È‚¢ */
 	::CheckDlgButton( hwndDlg, IDC_CHECK_bNotOverWriteCRLF, m_Common.m_bNotOverWriteCRLF );
+
+	//	URL‚ªƒNƒŠƒbƒN‚³‚ê‚½‚ç‘I‘ð‚·‚é‚© */	// 2007.02.11 genta ‚±‚Ìƒy�[ƒW‚ÖˆÚ“®
+	::CheckDlgButton( hwndDlg, IDC_CHECK_bSelectClickedURL, m_Common.m_bSelectClickedURL );
 	return;
 }
 
@@ -222,6 +227,9 @@
 
 	/* ‰ü�s‚Í�ã�‘‚«‚µ‚È‚¢ */
 	m_Common.m_bNotOverWriteCRLF = ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_bNotOverWriteCRLF );
+
+	/* URL‚ªƒNƒŠƒbƒN‚³‚ê‚½‚ç‘I‘ð‚·‚é‚© */	// 2007.02.11 genta ‚±‚Ìƒy�[ƒW‚ÖˆÚ“®
+	m_Common.m_bSelectClickedURL = ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_bSelectClickedURL );
 	return TRUE;
 }
 
Index: sakura_core/CPropCommon.cpp
===================================================================
--- sakura_core/CPropCommon.cpp	(revision 1065)
+++ sakura_core/CPropCommon.cpp	(working copy)
@@ -423,7 +423,8 @@
 		{ "ƒtƒ@ƒCƒ‹",		IDD_PROP_FILE,		DlgProc_PROP_FILE },
 		{ "ƒoƒbƒNƒAƒbƒv",	IDD_PROP_BACKUP,	DlgProc_PROP_BACKUP },
 		{ "�‘Ž®",			IDD_PROP_FORMAT,	DlgProc_PROP_FORMAT },
-		{ "ƒNƒŠƒbƒJƒuƒ‹URL",IDD_PROP_URL,		DlgProc_PROP_URL },
+		//	Feb. 11, 2007 genta URL‚ðTAB‚Æ“ü‚êŠ·‚¦
+		{ "ƒ^ƒuƒo�[",		IDD_PROP_TAB,		DlgProc_PROP_TAB },
 		{ "Grep",			IDD_PROP_GREP,		DlgProc_PROP_GREP },
 		{ "ƒL�[Š„‚è“–‚Ä",	IDD_PROP_KEYBIND,	DlgProc_PROP_KEYBIND },
 		{ "ƒJƒXƒ^ƒ€ƒ�ƒjƒ…�[",IDD_PROP_CUSTMENU,	DlgProc_PROP_CUSTMENU },
@@ -1082,8 +1083,8 @@
 	case IDD_PROP_WIN:
 		nContextID = ::FuncID_To_HelpContextID(F_OPTION_WINDOW);
 		break;
-	case IDD_PROP_URL:
-		nContextID = ::FuncID_To_HelpContextID(F_OPTION_URL);
+	case IDD_PROP_TAB:
+		nContextID = ::FuncID_To_HelpContextID(F_OPTION_TAB);
 		break;
 	case IDD_PROP_GREP:
 		nContextID = ::FuncID_To_HelpContextID(F_OPTION_GREP);
Index: sakura_core/CPropComTab.cpp
===================================================================
--- sakura_core/CPropComTab.cpp	(revision 0)
+++ sakura_core/CPropComTab.cpp	(revision 0)
@@ -0,0 +1,172 @@
+/*!	@file
+	@brief ‹¤’Ê�Ý’èƒ_ƒCƒAƒ�ƒOƒ{ƒbƒNƒX�A�uƒ^ƒuƒo�[�vƒy�[ƒW
+
+	@author Norio Nakatani
+	@date 2007.02.11 genta ‹¤’Ê�Ý’è‚É�V‹Kƒ^ƒu‚ð’Ç‰Á
+*/
+/*
+	Copyright (C) 1998-2001, Norio Nakatani
+	Copyright (C) 2007, genta
+	Copyright (C) 2001, MIK, genta
+	Copyright (C) 2002, YAZAKI, MIK
+	Copyright (C) 2003, KEITA
+	Copyright (C) 2006, ryoji
+	Copyright (C) 2007, genta
+*/
+
+#include "stdafx.h"
+#include "CPropCommon.h"
+
+#include "sakura.hh"
+static const DWORD p_helpids[] = {
+	IDC_CHECK_SameTabWidth,			HIDC_CHECK_SameTabWidth,		//“™•�	// 2006.08.06 ryoji
+	IDC_CHECK_DispTabIcon,			HIDC_CHECK_DispTabIcon,			//ƒAƒCƒRƒ“•\Ž¦	// 2006.08.06 ryoji
+	IDC_CHECK_SortTabList,			HIDC_CHECK_SortTabList,			//ƒ^ƒuˆê——ƒ\�[ƒg	// 2006.08.06 ryoji
+	IDC_CHECK_DispTabWndMultiWin,	HIDC_CHECK_DispTabWndMultiWin,	//ƒ^ƒuƒEƒCƒ“ƒhƒE•\Ž¦	//@@@ 2003.05.31 MIK
+	IDC_TABWND_CAPTION,				HIDC_TABWND_CAPTION,			//ƒ^ƒuƒEƒCƒ“ƒhƒEƒLƒƒƒvƒVƒ‡ƒ“	//@@@ 2003.06.15 MIK
+	0, 0
+};
+
+//	From Here Jun. 2, 2001 genta
+/*!
+	@param hwndDlg[in] ƒ_ƒCƒAƒ�ƒOƒ{ƒbƒNƒX‚ÌWindow Handle
+	@param uMsg[in] ƒ�ƒbƒZ�[ƒW
+	@param wParam[in] ƒpƒ‰ƒ��[ƒ^1
+	@param lParam[in] ƒpƒ‰ƒ��[ƒ^2
+*/
+INT_PTR CALLBACK CPropCommon::DlgProc_PROP_TAB(
+	HWND hwndDlg, UINT uMsg, WPARAM wParam, LPARAM lParam )
+{
+	return DlgProc( &CPropCommon::DispatchEvent_PROP_TAB, hwndDlg, uMsg, wParam, lParam );
+}
+//	To Here Jun. 2, 2001 genta
+
+/* ƒ�ƒbƒZ�[ƒW�ˆ—� */
+INT_PTR CPropCommon::DispatchEvent_PROP_TAB( HWND hwndDlg, UINT uMsg, WPARAM wParam, LPARAM lParam )
+{
+	NMHDR*		pNMHDR;
+	NM_UPDOWN*	pMNUD;
+	int			idCtrl;
+
+	switch( uMsg ){
+
+	case WM_INITDIALOG:
+		/* ƒ_ƒCƒAƒ�ƒOƒf�[ƒ^‚Ì�Ý’è p1 */
+		SetData_PROP_TAB( hwndDlg );
+		// Modified by KEITA for WIN64 2003.9.6
+		::SetWindowLongPtr( hwndDlg, DWLP_USER, lParam );
+
+		/* ƒ†�[ƒU�[‚ªƒGƒfƒBƒbƒg ƒRƒ“ƒgƒ��[ƒ‹‚É“ü—Í‚Å‚«‚éƒeƒLƒXƒg‚Ì’·‚³‚ð�§ŒÀ‚·‚é */
+
+		return TRUE;
+	case WM_NOTIFY:
+		idCtrl = (int)wParam;
+		pNMHDR = (NMHDR*)lParam;
+		pMNUD  = (NM_UPDOWN*)lParam;
+//		switch( idCtrl ){
+//		default:
+			switch( pNMHDR->code ){
+			case PSN_HELP:
+				OnHelp( hwndDlg, IDD_PROP_TAB );
+				return TRUE;
+			case PSN_KILLACTIVE:
+				/* ƒ_ƒCƒAƒ�ƒOƒf�[ƒ^‚ÌŽæ“¾ p1 */
+				GetData_PROP_TAB( hwndDlg );
+				return TRUE;
+//@@@ 2002.01.03 YAZAKI �ÅŒã‚É•\Ž¦‚µ‚Ä‚¢‚½ƒV�[ƒg‚ð�³‚µ‚­Šo‚¦‚Ä‚¢‚È‚¢ƒoƒO�C�³
+			case PSN_SETACTIVE:
+				m_nPageNum = ID_PAGENUM_TAB;
+				return TRUE;
+			}
+//			break;	/* default */
+//		}
+		break;	/* WM_NOTIFY */
+
+	case WM_COMMAND:
+		{
+			WORD wNotifyCode = HIWORD(wParam);	/* ’Ê’mƒR�[ƒh */
+			WORD wID = LOWORD(wParam);	/* �€–ÚID¤ ƒRƒ“ƒgƒ��[ƒ‹ID¤ ‚Ü‚½‚ÍƒAƒNƒZƒ‰ƒŒ�[ƒ^ID */
+			if( wNotifyCode == BN_CLICKED &&
+				wID == IDC_CHECK_DispTabWndMultiWin ){
+				
+				EnableTabPropInput( hwndDlg );
+			}
+		}
+		break;
+//@@@ 2001.02.04 Start by MIK: Popup Help
+	case WM_HELP:
+		{
+			HELPINFO *p = (HELPINFO *)lParam;
+			MyWinHelp( (HWND)p->hItemHandle, m_szHelpFile, HELP_WM_HELP, (ULONG_PTR)(LPVOID)p_helpids );	// 2006.10.10 ryoji MyWinHelp‚É•Ï�X‚É•Ï�X
+		}
+		return TRUE;
+		/*NOTREACHED*/
+		//break;
+//@@@ 2001.02.04 End
+
+//@@@ 2001.12.22 Start by MIK: Context Menu Help
+	//Context Menu
+	case WM_CONTEXTMENU:
+		MyWinHelp( hwndDlg, m_szHelpFile, HELP_CONTEXTMENU, (ULONG_PTR)(LPVOID)p_helpids );	// 2006.10.10 ryoji MyWinHelp‚É•Ï�X‚É•Ï�X
+		return TRUE;
+//@@@ 2001.12.22 End
+
+	}
+	return FALSE;
+}
+
+
+/* ƒ_ƒCƒAƒ�ƒOƒf�[ƒ^‚Ì�Ý’è */
+void CPropCommon::SetData_PROP_TAB( HWND hwndDlg )
+{
+	//	Feb. 11, 2007 genta�uƒEƒBƒ“ƒhƒE�vƒV�[ƒg‚æ‚èˆÚ“®
+	::CheckDlgButton( hwndDlg, IDC_CHECK_SameTabWidth, m_Common.m_bSameTabWidth );	//@@@ 2006.01.28 ryoji
+	::CheckDlgButton( hwndDlg, IDC_CHECK_DispTabIcon, m_Common.m_bDispTabIcon );	//@@@ 2006.01.28 ryoji
+	::CheckDlgButton( hwndDlg, IDC_CHECK_SortTabList, m_Common.m_bSortTabList );			//@@@ 2006.03.23 fon
+	::CheckDlgButton( hwndDlg, IDC_CHECK_DispTabWndMultiWin, ! m_Common.m_bDispTabWndMultiWin ); //@@@ 2003.05.31 MIK
+	::SendMessage( ::GetDlgItem( hwndDlg, IDC_TABWND_CAPTION ), EM_LIMITTEXT, (WPARAM)(sizeof( m_Common.m_szTabWndCaption ) - 1 ), (LPARAM)0 );
+	::SetDlgItemText( hwndDlg, IDC_TABWND_CAPTION, m_Common.m_szTabWndCaption );
+
+	//	Feb. 11, 2007 genta �V‹K�ì�¬
+	::CheckDlgButton( hwndDlg, IDC_CHECK_RetainEmptyWindow, m_Common.m_bTab_RetainEmptyWin );
+	::CheckDlgButton( hwndDlg, IDC_CHECK_CloseOneWin, m_Common.m_bTab_CloseOneWin );
+	
+	EnableTabPropInput(hwndDlg);
+	return;
+}
+
+/* ƒ_ƒCƒAƒ�ƒOƒf�[ƒ^‚ÌŽæ“¾ */
+int CPropCommon::GetData_PROP_TAB( HWND hwndDlg )
+{
+	//	Feb. 11, 2007 genta�uƒEƒBƒ“ƒhƒE�vƒV�[ƒg‚æ‚èˆÚ“®
+	m_Common.m_bSameTabWidth = ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_SameTabWidth );		// 2006.01.28 ryoji
+	m_Common.m_bDispTabIcon = ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_DispTabIcon );		// 2006.01.28 ryoji
+	m_Common.m_bSortTabList = ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_SortTabList );		// 2006.03.23 fon
+	m_Common.m_bDispTabWndMultiWin =
+		( ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_DispTabWndMultiWin ) == BST_CHECKED ) ? FALSE : TRUE;
+	::GetDlgItemText( hwndDlg, IDC_TABWND_CAPTION, m_Common.m_szTabWndCaption, sizeof( m_Common.m_szTabWndCaption ) );
+
+	//	Feb. 11, 2007 genta �V‹K�ì�¬
+	m_Common.m_bTab_RetainEmptyWin = ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_RetainEmptyWindow );
+	m_Common.m_bTab_CloseOneWin = ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_CloseOneWin );
+
+	return TRUE;
+}
+
+/*! �uƒ^ƒuƒo�[�vƒV�[ƒg�ã‚ÌƒAƒCƒeƒ€‚Ì—LŒø�E–³Œø‚ð“K�Ø‚É�Ý’è‚·‚é
+
+	@date 2007.02.12 genta �V‹K�ì�¬
+*/
+void CPropCommon::EnableTabPropInput(HWND hwndDlg)
+{
+	if( ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_DispTabWndMultiWin ) )
+	{
+		::EnableWindow( ::GetDlgItem( hwndDlg, IDC_CHECK_RetainEmptyWindow ), TRUE );
+		::EnableWindow( ::GetDlgItem( hwndDlg, IDC_CHECK_CloseOneWin       ), TRUE );
+	}
+	else {
+		::EnableWindow( ::GetDlgItem( hwndDlg, IDC_CHECK_RetainEmptyWindow ), FALSE );
+		::EnableWindow( ::GetDlgItem( hwndDlg, IDC_CHECK_CloseOneWin       ), FALSE );
+	}
+}
+/*[EOF]*/

Property changes on: sakura_core\CPropComTab.cpp
___________________________________________________________________
Name: svn:mime-type
   + text/plain
Name: svn:keywords
   + Id Revision
Name: svn:eol-style
   + native

Index: sakura_core/CPropComWin.cpp
===================================================================
--- sakura_core/CPropComWin.cpp	(revision 1065)
+++ sakura_core/CPropComWin.cpp	(working copy)
@@ -27,7 +27,6 @@
 static const DWORD p_helpids[] = {	//11200
 	IDC_CHECK_DispFUNCKEYWND,		HIDC_CHECK_DispFUNCKEYWND,		//ƒtƒ@ƒ“ƒNƒVƒ‡ƒ“ƒL�[•\Ž¦
 	IDC_CHECK_DispTabWnd,			HIDC_CHECK_DispTabWnd,			//ƒ^ƒuƒEƒCƒ“ƒhƒE•\Ž¦	//@@@ 2003.05.31 MIK
-	IDC_CHECK_DispTabWndMultiWin,	HIDC_CHECK_DispTabWndMultiWin,	//ƒ^ƒuƒEƒCƒ“ƒhƒE•\Ž¦	//@@@ 2003.05.31 MIK
 	IDC_CHECK_DispSTATUSBAR,		HIDC_CHECK_DispSTATUSBAR,		//ƒXƒe�[ƒ^ƒXƒo�[•\Ž¦
 	IDC_CHECK_DispTOOLBAR,			HIDC_CHECK_DispTOOLBAR,			//ƒc�[ƒ‹ƒo�[•\Ž¦
 	IDC_CHECK_bScrollBarHorz,		HIDC_CHECK_bScrollBarHorz,		//�…•½ƒXƒNƒ��[ƒ‹ƒo�[
@@ -46,11 +45,8 @@
 	IDC_SPIN_FUNCKEYWND_GROUPNUM,	HIDC_EDIT_FUNCKEYWND_GROUPNUM,
 	IDC_WINCAPTION_ACTIVE,			HIDC_WINCAPTION_ACTIVE,			//ƒAƒNƒeƒBƒuŽž	//@@@ 2003.06.15 MIK
 	IDC_WINCAPTION_INACTIVE,		HIDC_WINCAPTION_INACTIVE,		//”ñƒAƒNƒeƒBƒuŽž	//@@@ 2003.06.15 MIK
-	IDC_TABWND_CAPTION,				HIDC_TABWND_CAPTION,			//ƒ^ƒuƒEƒCƒ“ƒhƒEƒLƒƒƒvƒVƒ‡ƒ“	//@@@ 2003.06.15 MIK
 	IDC_BUTTON_WINSIZE,				HIDC_BUTTON_WINSIZE,			//ˆÊ’u‚Æ‘å‚«‚³‚Ì�Ý’è	// 2006.08.06 ryoji
-	IDC_CHECK_SameTabWidth,			HIDC_CHECK_SameTabWidth,		//“™•�	// 2006.08.06 ryoji
-	IDC_CHECK_DispTabIcon,			HIDC_CHECK_DispTabIcon,			//ƒAƒCƒRƒ“•\Ž¦	// 2006.08.06 ryoji
-	IDC_CHECK_SortTabList,			HIDC_CHECK_SortTabList,			//ƒ^ƒuˆê——ƒ\�[ƒg	// 2006.08.06 ryoji
+	//	Feb. 11, 2007 genta TABŠÖ˜A‚Í�uƒ^ƒuƒo�[�vƒV�[ƒg‚ÖˆÚ“®
 //	IDC_STATIC,						-1,
 	0, 0
 };
@@ -237,19 +233,6 @@
 				EnableWinPropInput( hwndDlg );
 				break;
 
-			//@@@ 2003.06.13 MIK
-			case IDC_CHECK_DispTabWnd:
-				if( ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_DispTabWnd ) )
-				{
-					::EnableWindow( ::GetDlgItem( hwndDlg, IDC_CHECK_DispTabWndMultiWin ), TRUE );
-					//::EnableWindow( ::GetDlgItem( hwndDlg, IDC_TABWND_CAPTION           ), TRUE );
-				}
-				else
-				{
-					::EnableWindow( ::GetDlgItem( hwndDlg, IDC_CHECK_DispTabWndMultiWin ), FALSE );
-					//::EnableWindow( ::GetDlgItem( hwndDlg, IDC_TABWND_CAPTION           ), FALSE );
-				}
-				break;
 			// From Here 2004.05.13 Moca �uˆÊ’u‚Æ‘å‚«‚³‚Ì�Ý’è�vƒ{ƒ^ƒ“
 			//	ƒEƒBƒ“ƒhƒE�Ý’èƒ_ƒCƒAƒ�ƒO‚É‚Ä‹N“®Žž‚ÌƒEƒBƒ“ƒhƒE�ó‘ÔŽw’è
 			case IDC_BUTTON_WINSIZE:
@@ -324,18 +307,10 @@
 	//From Here@@@ 2003.06.13 MIK
 	/* ŽŸ‰ñƒEƒBƒ“ƒhƒE‚ðŠJ‚¢‚½‚Æ‚«ƒ^ƒu‚ð•\Ž¦‚·‚é */
 	::CheckDlgButton( hwndDlg, IDC_CHECK_DispTabWnd, m_Common.m_bDispTabWnd );	//@@@ 2003.05.31 MIK
-	::CheckDlgButton( hwndDlg, IDC_CHECK_DispTabWndMultiWin, m_Common.m_bDispTabWndMultiWin );	//@@@ 2003.05.31 MIK
-	if( FALSE == m_Common.m_bDispTabWnd )
-	{
-		::EnableWindow( ::GetDlgItem( hwndDlg, IDC_CHECK_DispTabWndMultiWin ), FALSE );
-		//::EnableWindow( ::GetDlgItem( hwndDlg, IDC_TABWND_CAPTION           ), FALSE );
-	}
-	::SendMessage( ::GetDlgItem( hwndDlg, IDC_TABWND_CAPTION ), EM_LIMITTEXT, (WPARAM)(sizeof( m_Common.m_szTabWndCaption ) - 1 ), (LPARAM)0 );
-	::SetDlgItemText( hwndDlg, IDC_TABWND_CAPTION, m_Common.m_szTabWndCaption );
+	//	Feb. 12, 2007 genta TABŠÖ˜A‚Í�uƒ^ƒuƒo�[�vƒV�[ƒg‚ÖˆÚ“®
+
 	//To Here@@@ 2003.06.13 MIK
-	::CheckDlgButton( hwndDlg, IDC_CHECK_SameTabWidth, m_Common.m_bSameTabWidth );	//@@@ 2006.01.28 ryoji
-	::CheckDlgButton( hwndDlg, IDC_CHECK_DispTabIcon, m_Common.m_bDispTabIcon );	//@@@ 2006.01.28 ryoji
-	::CheckDlgButton( hwndDlg, IDC_CHECK_SortTabList, m_Common.m_bSortTabList );			//@@@ 2006.03.23 fon
+	//	Feb. 11, 2007 genta TABŠÖ˜A‚Í�uƒ^ƒuƒo�[�vƒV�[ƒg‚ÖˆÚ“®
 
 	/* ŽŸ‰ñƒEƒBƒ“ƒhƒE‚ðŠJ‚¢‚½‚Æ‚«ƒXƒe�[ƒ^ƒXƒo�[‚ð•\Ž¦‚·‚é */
 	::CheckDlgButton( hwndDlg, IDC_CHECK_DispSTATUSBAR, m_Common.m_bDispSTATUSBAR );
@@ -417,12 +392,8 @@
 	//From Here@@@ 2003.06.13 MIK
 	/* ŽŸ‰ñƒEƒBƒ“ƒhƒE‚ðŠJ‚¢‚½‚Æ‚«ƒ^ƒu‚ð•\Ž¦‚·‚é */
 	m_Common.m_bDispTabWnd = ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_DispTabWnd );
-	m_Common.m_bDispTabWndMultiWin = ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_DispTabWndMultiWin );
-	::GetDlgItemText( hwndDlg, IDC_TABWND_CAPTION, m_Common.m_szTabWndCaption, sizeof( m_Common.m_szTabWndCaption ) );
+	//	Feb. 12, 2007 genta TABŠÖ˜A‚Í�uƒ^ƒuƒo�[�vƒV�[ƒg‚ÖˆÚ“®
 	//To Here@@@ 2003.06.13 MIK
-	m_Common.m_bSameTabWidth = ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_SameTabWidth );		// 2006.01.28 ryoji
-	m_Common.m_bDispTabIcon = ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_DispTabIcon );		// 2006.01.28 ryoji
-	m_Common.m_bSortTabList = ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_SortTabList );		// 2006.03.23 fon
 
 	/* ŽŸ‰ñƒEƒBƒ“ƒhƒE‚ðŠJ‚¢‚½‚Æ‚«ƒXƒe�[ƒ^ƒXƒo�[‚ð•\Ž¦‚·‚é */
 	m_Common.m_bDispSTATUSBAR = ::IsDlgButtonChecked( hwndDlg, IDC_CHECK_DispSTATUSBAR );
Index: sakura_core/CShareData.cpp
===================================================================
--- sakura_core/CShareData.cpp	(revision 1065)
+++ sakura_core/CShareData.cpp	(working copy)
@@ -200,9 +200,13 @@
 	Version 70:
 	[‚·‚×‚Ä•Â‚¶‚é]‚Å‘¼‚É•Ò�W—p‚ÌƒEƒBƒ“ƒhƒE‚ª‚ ‚ê‚ÎŠm”F‚·‚é 2006.12.25 ryoji
 
+	Version 71:
+	ƒ^ƒu‚ð•Â‚¶‚é“®�ì‚ð�§Œä‚·‚éƒIƒvƒVƒ‡ƒ“2‚Â‚ð’Ç‰Á 2007.02.11 genta
+		m_bRetainEmptyTab, m_bCloseOneWinInTabMode
+
 */
 
-const unsigned int uShareDataVersion = 70;
+const unsigned int uShareDataVersion = 0x7ffff069;
 
 /*
 ||	Singleton•—
@@ -485,6 +489,8 @@
 		m_pShareData->m_Common.m_bSameTabWidth = FALSE;			//ƒ^ƒu‚ð“™•�‚É‚·‚é			//@@@ 2006.01.28 ryoji
 		m_pShareData->m_Common.m_bDispTabIcon = FALSE;			//ƒ^ƒu‚ÉƒAƒCƒRƒ“‚ð•\Ž¦‚·‚é	//@@@ 2006.01.28 ryoji
 		m_pShareData->m_Common.m_bSortTabList = TRUE;			//ƒ^ƒuˆê——‚ðƒ\�[ƒg‚·‚é		//@@@ 2006.05.10 ryoji
+		m_pShareData->m_Common.m_bTab_RetainEmptyWin = TRUE;	// �ÅŒã‚Ìƒtƒ@ƒCƒ‹‚ª•Â‚¶‚ç‚ê‚½‚Æ‚«(–³‘è)‚ðŽc‚·	// 2007.02.11 genta
+		m_pShareData->m_Common.m_bTab_CloseOneWin = FALSE;	// ƒ^ƒuƒ‚�[ƒh‚Å‚àƒEƒBƒ“ƒhƒE‚Ì•Â‚¶‚éƒ{ƒ^ƒ“‚ÅŒ»�Ý‚Ìƒtƒ@ƒCƒ‹‚Ì‚Ý•Â‚¶‚é	// 2007.02.11 genta
 
 		m_pShareData->m_Common.m_bSplitterWndHScroll = TRUE;	// 2001/06/20 asa-o •ªŠ„ƒEƒBƒ“ƒhƒE‚Ì�…•½ƒXƒNƒ��[ƒ‹‚Ì“¯Šú‚ð‚Æ‚é
 		m_pShareData->m_Common.m_bSplitterWndVScroll = TRUE;	// 2001/06/20 asa-o •ªŠ„ƒEƒBƒ“ƒhƒE‚Ì�‚’¼ƒXƒNƒ��[ƒ‹‚Ì“¯Šú‚ð‚Æ‚é
Index: sakura_core/CShareData.h
===================================================================
--- sakura_core/CShareData.h	(revision 1065)
+++ sakura_core/CShareData.h	(working copy)
@@ -483,6 +483,9 @@
 
 	BOOL				m_bDispTabWnd;					//ƒ^ƒuƒEƒCƒ“ƒhƒE•\Ž¦‚·‚é	//@@@ 2003.05.31 MIK
 	BOOL				m_bDispTabWndMultiWin;			//ƒ^ƒu‚ð‚Ü‚Æ‚ß‚È‚¢	//@@@ 2003.05.31 MIK
+	BOOL				m_bTab_RetainEmptyWin;			//!< �ÅŒã‚Ì•¶�‘‚ª•Â‚¶‚ç‚ê‚½‚Æ‚«(–³‘è)‚ðŽc‚·
+	BOOL				m_bTab_CloseOneWin;		//!< ƒ^ƒuƒ‚�[ƒh‚Å‚àƒEƒBƒ“ƒhƒE‚Ì•Â‚¶‚éƒ{ƒ^ƒ“‚ÅŒ»�Ý‚Ìƒtƒ@ƒCƒ‹‚Ì‚Ý•Â‚¶‚é
+
 	char				m_szTabWndCaption[MAX_CAPTION_CONF_LEN];	//ƒ^ƒuƒEƒCƒ“ƒhƒEƒLƒƒƒvƒVƒ‡ƒ“	//@@@ 2003.06.13 MIK
 	BOOL				m_bSameTabWidth;				//ƒ^ƒu‚ð“™•�‚É‚·‚é			//@@@ 2006.01.28 ryoji
 	BOOL				m_bDispTabIcon;					//ƒ^ƒu‚ÉƒAƒCƒRƒ“‚ð•\Ž¦‚·‚é	//@@@ 2006.01.28 ryoji
Index: sakura_core/CShareData_new.cpp
===================================================================
--- sakura_core/CShareData_new.cpp	(revision 1065)
+++ sakura_core/CShareData_new.cpp	(working copy)
@@ -520,6 +520,8 @@
 	cProfile.IOProfileData( pszSecName, "bSameTabWidth"			, common.m_bSameTabWidth );	// 2006.01.28 ryoji ƒ^ƒu‚ð“™•�‚É‚·‚é
 	cProfile.IOProfileData( pszSecName, "bDispTabIcon"			, common.m_bDispTabIcon );	// 2006.01.28 ryoji ƒ^ƒu‚ÉƒAƒCƒRƒ“‚ð•\Ž¦‚·‚é
 	cProfile.IOProfileData( pszSecName, "bSortTabList"			, common.m_bSortTabList );	// 2006.05.10 ryoji ƒ^ƒuˆê——‚ðƒ\�[ƒg‚·‚é
+	cProfile.IOProfileData( pszSecName, "bTab_RetainEmptyWin"	, common.m_bTab_RetainEmptyWin );	// �ÅŒã‚Ìƒtƒ@ƒCƒ‹‚ª•Â‚¶‚ç‚ê‚½‚Æ‚«(–³‘è)‚ðŽc‚·	// 2007.02.11 genta
+	cProfile.IOProfileData( pszSecName, "bTab_CloseOneWin"	, common.m_bTab_CloseOneWin );	// ƒ^ƒuƒ‚�[ƒh‚Å‚àƒEƒBƒ“ƒhƒE‚Ì•Â‚¶‚éƒ{ƒ^ƒ“‚ÅŒ»�Ý‚Ìƒtƒ@ƒCƒ‹‚Ì‚Ý•Â‚¶‚é	// 2007.02.11 genta
 	
 	// 2001/06/20 asa-o •ªŠ„ƒEƒBƒ“ƒhƒE‚ÌƒXƒNƒ��[ƒ‹‚Ì“¯Šú‚ð‚Æ‚é
 	cProfile.IOProfileData( pszSecName, "bSplitterWndHScroll"	, common.m_bSplitterWndHScroll );
Index: sakura_core/etc_uty.cpp
===================================================================
--- sakura_core/etc_uty.cpp	(revision 1065)
+++ sakura_core/etc_uty.cpp	(working copy)
@@ -2168,7 +2168,6 @@
 	case F_OPTION_FILE:		return HLP000083;	/* ‹¤’Ê�Ý’è�wƒtƒ@ƒCƒ‹�x */
 	case F_OPTION_BACKUP:	return HLP000145;	/* ‹¤’Ê�Ý’è�wƒoƒbƒNƒAƒbƒv�x */
 	case F_OPTION_FORMAT:	return HLP000082;	/* ‹¤’Ê�Ý’è�w�‘Ž®�x */
-	case F_OPTION_URL:		return HLP000147;	/* ‹¤’Ê�Ý’è�wƒNƒŠƒbƒJƒuƒ‹URL�x */
 	case F_OPTION_GREP:		return HLP000148;	/* ‹¤’Ê�Ý’è�wGrep�x */
 	case F_OPTION_KEYBIND:	return HLP000084;	/* ‹¤’Ê�Ý’è�wƒL�[Š„‚è“–‚Ä�x */
 	case F_OPTION_CUSTMENU:	return HLP000087;	/* ‹¤’Ê�Ý’è�wƒJƒXƒ^ƒ€ƒ�ƒjƒ…�[�x */
Index: sakura_core/Funccode.h
===================================================================
--- sakura_core/Funccode.h	(revision 1065)
+++ sakura_core/Funccode.h	(working copy)
@@ -308,7 +308,7 @@
 #define F_OPTION_FILE		32003	/* ‹¤’Ê�Ý’è�wƒtƒ@ƒCƒ‹�x */
 #define F_OPTION_BACKUP		32004	/* ‹¤’Ê�Ý’è�wƒoƒbƒNƒAƒbƒv�x */
 #define F_OPTION_FORMAT		32005	/* ‹¤’Ê�Ý’è�w�‘Ž®�x */
-#define F_OPTION_URL		32006	/* ‹¤’Ê�Ý’è�wƒNƒŠƒbƒJƒuƒ‹URL�x */
+//#define F_OPTION_URL		32006	/* ‹¤’Ê�Ý’è�wƒNƒŠƒbƒJƒuƒ‹URL�x */
 #define F_OPTION_GREP		32007	/* ‹¤’Ê�Ý’è�wGrep�x */
 #define F_OPTION_KEYBIND	32008	/* ‹¤’Ê�Ý’è�wƒL�[Š„‚è“–‚Ä�x */
 #define F_OPTION_CUSTMENU	32009	/* ‹¤’Ê�Ý’è�wƒJƒXƒ^ƒ€ƒ�ƒjƒ…�[�x */
@@ -318,6 +318,7 @@
 //To here  Stonee, 2001/05/18
 #define F_OPTION_MACRO		32013	/* ‹¤’Ê�Ý’è�wƒ}ƒNƒ��x */
 #define F_OPTION_FNAME		32014	/* ‹¤’Ê�Ý’è�wƒtƒ@ƒCƒ‹–¼•\Ž¦�x */
+#define F_OPTION_TAB		32015	/* ‹¤’Ê�Ý’è�wƒ^ƒu�x*/ // Feb. 11, 2007 genta ’Ç‰Á
 
 #define F_FONT				31120	/* ƒtƒHƒ“ƒg�Ý’è */
 #define F_WRAPWINDOWWIDTH	31140	//Œ»�Ý‚ÌƒEƒBƒ“ƒhƒE•�‚Å�Ü‚è•Ô‚µ */	//Oct. 7, 2000 JEPRO WRAPWINDIWWIDTH ‚ð WRAPWINDOWWIDTH ‚É•Ï�X
Index: sakura_core/sakura_rc.h
===================================================================
--- sakura_core/sakura_rc.h	(revision 1065)
+++ sakura_core/sakura_rc.h	(working copy)
@@ -579,6 +579,8 @@
 #define IDC_CHECK_NoFilterSaveNew       1515
 #define IDC_CHECK_NoFilterSaveFile      1516
 #define IDC_CHECK_CLOSEALLCONFIRM       1517
+#define IDC_CHECK_RetainEmptyWindow     1518
+#define IDC_CHECK_CloseOneWin           1519
 #define IDD_PROP_TOOLBAR                1539
 #define IDC_CHECK_SortTabList           1540
 #define IDM_POPLAST                     4047
@@ -599,7 +601,7 @@
 #define IDD_PROP_KEYBIND                5107
 #define IDD_PROP_WIN                    5108
 #define IDD_PROP_EDIT                   5109
-#define IDD_PROP_URL                    5110
+#define IDD_PROP_TAB                    5110
 #define IDD_PROP_GREP                   5111
 #define IDD_PROP_BACKUP                 5112
 #define IDD_OPERATIONRUNNING            5113
@@ -641,7 +643,7 @@
 #ifndef APSTUDIO_READONLY_SYMBOLS
 #define _APS_NEXT_RESOURCE_VALUE        245
 #define _APS_NEXT_COMMAND_VALUE         4073
-#define _APS_NEXT_CONTROL_VALUE         1518
+#define _APS_NEXT_CONTROL_VALUE         1520
 #define _APS_NEXT_SYMED_VALUE           103
 #endif
 #endif
Index: sakura_core/sakura_rc.hm
===================================================================
--- sakura_core/sakura_rc.hm	(revision 1065)
+++ sakura_core/sakura_rc.hm	(working copy)
@@ -1,4 +1,4 @@
-// Microsoft Developer Studio generated Help ID include file.
+// Microsoft Visual C++ generated Help ID include file.
 // Used by sakura_rc.rc
 //
 #define HIDCANCEL                       0x80a80002    // IDD_COMPARE
@@ -30,21 +30,18 @@
 #define HIDC_BUTTON_INSERTSEPARATOR     0x93ef0440    // IDD_PROP_CUSTMENU
 #define HIDC_BUTTON_INSERTWRAP          0x86030441    // IDD_PROP_TOOLBAR
 #define HIDC_BUTTON_JUMP                0x8076056c    // IDD_JUMP
-#define HIDC_BUTTON_KEYHELP_ADD         0x93ff1407    // IDD_PROP_KEYHELP
+#define HIDC_BUTTON_KEYCLEAN            0x809905da    // IDD_PROP_KEYWORD
 #define HIDC_BUTTON_KEYHELP_DEL         0x93ff1409    // IDD_PROP_KEYHELP
 #define HIDC_BUTTON_KEYHELP_DOWN        0x93ff140c    // IDD_PROP_KEYHELP
-#define HIDC_BUTTON_KEYHELP_REF         0x93ff140e    // IDD_PROP_KEYHELP
+#define HIDC_BUTTON_KEYHELP_EXPORT      0x93ff140f    // IDD_PROP_KEYHELP
+#define HIDC_BUTTON_KEYHELP_IMPORT      0x93ff1405    // IDD_PROP_KEYHELP
 #define HIDC_BUTTON_KEYHELP_INS         0x93ff1406    // IDD_PROP_KEYHELP
 #define HIDC_BUTTON_KEYHELP_LAST        0x93ff140d    // IDD_PROP_KEYHELP
+#define HIDC_BUTTON_KEYHELP_REF         0x93ff140e    // IDD_PROP_KEYHELP
 #define HIDC_BUTTON_KEYHELP_TOP         0x93ff140a    // IDD_PROP_KEYHELP
 #define HIDC_BUTTON_KEYHELP_UP          0x93ff140b    // IDD_PROP_KEYHELP
 #define HIDC_BUTTON_KEYHELP_UPD         0x93ff1408    // IDD_PROP_KEYHELP
-#define HIDC_BUTTON_KEYHELP_IMPORT      0x93ff1405    // IDD_PROP_KEYHELP
-#define HIDC_BUTTON_KEYHELP_EXPORT      0x93ff140f    // IDD_PROP_KEYHELP
-#define HIDC_BUTTON_KEYCLEAN            0x809905da    // IDD_PROP_KEYWORD
 #define HIDC_BUTTON_KEYSETRENAME        0x809905d9    // IDD_PROP_KEYWORD
-#define HIDC_BUTTON_KEYWORDHELPFILE_REF \
-                                        0x93fa0441    // IDD_PROPTYPESP2
 #define HIDC_BUTTON_KEYWORDHELPFONT     0x93f1044a    // IDD_PROP_HELPER
 #define HIDC_BUTTON_KEYWORD_SELECT      0x93f205d7    // IDD_PROP_COLOR
 #define HIDC_BUTTON_OPENEXTHTMLHELP     0x93f10449    // IDD_PROP_HELPER
@@ -65,7 +62,6 @@
 #define HIDC_BUTTON_RELEASE             0x93f303f8    // IDD_PROP_KEYBIND
 #define HIDC_BUTTON_REPALCE             0x8089043f    // IDD_REPLACE
 #define HIDC_BUTTON_REPALCEALL          0x8089046e    // IDD_REPLACE
-#define HIDC_BUTTON_REPLACEALL_LINE     0x80890470    // IDD_REPLACE
 #define HIDC_BUTTON_RULEFILE_REF        0x93ed0593    // IDD_PROPTYPESP1
 #define HIDC_BUTTON_SAMEBKCOLOR         0x93f20478    // IDD_PROP_COLOR
 #define HIDC_BUTTON_SAMETEXTCOLOR       0x93f20479    // IDD_PROP_COLOR
@@ -80,8 +76,6 @@
 #define HIDC_BUTTON_TYPEOPENHELP        0x93fa058e    // IDD_PROPTYPESP2
 #define HIDC_BUTTON_UP                  0x93ef0477    // IDD_PROP_CUSTMENU
 #define HIDC_BUTTON_WINSIZE             0x807a05d3    // IDD_FUNCLIST
-#define HIDC_CHECK_DOCICON              0x93ed0434    // IDD_PROPTYPESP1
-#define HIDC_CHECK_GREPREALTIME         0x93f705c7    // IDD_PROP_GREP
 #define HIDC_CHECK_ADDCRLFWHENCOPY      0x93f5045c    // IDD_PROP_EDIT
 #define HIDC_CHECK_ALT                  0x93f30438    // IDD_PROP_KEYBIND
 #define HIDC_CHECK_ANYWHERE             0x80e405de    // IDD_TAGJUMPLIST
@@ -100,7 +94,6 @@
 #define HIDC_CHECK_BACKUP_RETAINEXT     0x93f80559    // IDD_PROP_BACKUP
 #define HIDC_CHECK_BACKUP_SEC           0x93f8043b    // IDD_PROP_BACKUP
 #define HIDC_CHECK_BACKUP_YEAR          0x93f80438    // IDD_PROP_BACKUP
-#define HIDC_CHECK_CLICKKEYSEARCH       0x93f10524    // IDD_PROP_HELPER
 #define HIDC_CHECK_BOM                  0xffff05c6    // "IDD_FILEOPEN"
 #define HIDC_CHECK_COPYnDISABLESELECTEDAREA \
                                         0x93f5050b    // IDD_PROP_EDIT
@@ -112,14 +105,15 @@
 #define HIDC_CHECK_DIFF_OPT_SPCCHG      0x93fb0599    // IDD_DIFF
 #define HIDC_CHECK_DIFF_OPT_TABSPC      0x93fb059b    // IDD_DIFF
 #define HIDC_CHECK_DISP                 0x93f204bc    // IDD_PROP_COLOR
+#define HIDC_CHECK_DOCICON              0x93ed0434    // IDD_PROPTYPESP1
 #define HIDC_CHECK_DRAGDROP             0x93f50509    // IDD_PROP_EDIT
 #define HIDC_CHECK_DROPSOURCE           0x93f5050a    // IDD_PROP_EDIT
 #define HIDC_CHECK_DispFUNCKEYWND       0x93f404a7    // IDD_PROP_WIN
 #define HIDC_CHECK_DispSTATUSBAR        0x93f40501    // IDD_PROP_WIN
 #define HIDC_CHECK_DispTOOLBAR          0x93f40444    // IDD_PROP_WIN
-#define HIDC_CHECK_DispTabIcon          0x93f40438    // IDD_PROP_WIN
+#define HIDC_CHECK_DispTabIcon          0x93f60438    // IDD_PROP_TAB
 #define HIDC_CHECK_DispTabWnd           0x93f40502    // IDD_PROP_WIN
-#define HIDC_CHECK_DispTabWndMultiWin   0x93f40591    // IDD_PROP_WIN
+#define HIDC_CHECK_DispTabWndMultiWin   0x93f60591    // IDD_PROP_TAB
 #define HIDC_CHECK_ENABLEUNMODIFIEDOVERWRITE \
                                         0x806e0507    // IDD_PROP_FILE
 #define HIDC_CHECK_EXCVLUSIVE_NO        0x806e042d    // IDD_PROP_FILE
@@ -130,6 +124,7 @@
 #define HIDC_CHECK_FAT                  0x93f204bd    // IDD_PROP_COLOR
 #define HIDC_CHECK_FREECARET            0x806b03f6    // IDD_PROP1P1
 #define HIDC_CHECK_GETSTDOUT            0x80b60531    // IDD_EXEC
+#define HIDC_CHECK_GREPREALTIME         0x93f705c7    // IDD_PROP_GREP
 #define HIDC_CHECK_GTJW_LDBLCLK         0x93f703ff    // IDD_PROP_GREP
 #define HIDC_CHECK_GTJW_RETURN          0x93f703f5    // IDD_PROP_GREP
 #define HIDC_CHECK_HOKANLOHICASE        0x93fa04c9    // IDD_PROPTYPESP2
@@ -172,15 +167,14 @@
                                         0x806b03f5    // IDD_PROP1P1
 #define HIDC_CHECK_STOPS_BOTH_ENDS_WHEN_SEARCH_WORD \
                                         0x806b03f4    // IDD_PROP1P1
-#define HIDC_CHECK_SameTabWidth         0x93f40578    // IDD_PROP_WIN
-#define HIDC_CHECK_SortTabList          0x93f40604    // IDD_PROP_WIN
+#define HIDC_CHECK_SameTabWidth         0x93f60578    // IDD_PROP_TAB
+#define HIDC_CHECK_SortTabList          0x93f60604    // IDD_PROP_TAB
 #define HIDC_CHECK_TAB_ARROW            0x93ed05b0    // IDD_PROPTYPESP1
 #define HIDC_CHECK_TAG_MAKE_RECURSE     0x80e505c0    // IDD_TAG_MAKE
 #define HIDC_CHECK_TILE_H               0x80a80510    // IDD_COMPARE
 #define HIDC_CHECK_TOOLBARISFLAT        0x86030434    // IDD_PROP_TOOLBAR
 #define HIDC_CHECK_TYPEHTMLHELPISSINGLE \
                                         0x93fa0590    // IDD_PROPTYPESP2
-#define HIDC_CHECK_TYPE_KEYHELPUSE      0x93ff1412    // IDD_PROP_KEYHELP
 #define HIDC_CHECK_UNDERLINE            0x93f2043d    // IDD_PROP_COLOR
 #define HIDC_CHECK_USETRAYICON          0x806b04ff    // IDD_PROP1P1
 #define HIDC_CHECK_WORDWRAP             0x80ae04ed    // IDD_PRINTSETTING
@@ -199,7 +193,7 @@
 #define HIDC_CHECK_bMenuIcon            0x93f40537    // IDD_PROP_WIN
 #define HIDC_CHECK_bNotOverWriteCRLF    0x93f50514    // IDD_PROP_EDIT
 #define HIDC_CHECK_bScrollBarHorz       0x93f40519    // IDD_PROP_WIN
-#define HIDC_CHECK_bSelectClickedURL    0x93f6050d    // IDD_PROP_URL
+#define HIDC_CHECK_bSelectClickedURL    0x93f5050d    // IDD_PROP_EDIT
 #define HIDC_CHECK_m_bHokanKey_RETURN   0x93f10521    // IDD_PROP_HELPER
 #define HIDC_CHECK_m_bHokanKey_RIGHT    0x93f10523    // IDD_PROP_HELPER
 #define HIDC_CHECK_m_bHokanKey_TAB      0x93f10522    // IDD_PROP_HELPER
@@ -261,7 +255,6 @@
 #define HIDC_EDIT_INYOUKIGOU            0x93f004aa    // IDD_PROP_FORMAT
 #define HIDC_EDIT_KEYHELP               0x93ff1403    // IDD_PROP_KEYHELP
 #define HIDC_EDIT_KEYSFUNC              0x93f304f9    // IDD_PROP_KEYBIND
-#define HIDC_EDIT_KEYWORDHELPFILE       0x93fa0440    // IDD_PROPTYPESP2
 #define HIDC_EDIT_KINSOKUHEAD           0x93ed0594    // IDD_PROPTYPESP1
 #define HIDC_EDIT_KINSOKUTAIL           0x93ed0595    // IDD_PROPTYPESP1
 #define HIDC_EDIT_LINECOMMENT           0x93f20456    // IDD_PROP_COLOR
@@ -310,10 +303,10 @@
 #define HIDC_FRAME_REGEX                0x80db0588    // IDD_PROP_REGEX
 #define HIDC_HOTKEY_TRAYMENU            0x806b0506    // IDD_PROP1P1
 #define HIDC_KEYWORD                    0x80e405db    // IDD_TAGJUMPLIST
-#define HIDC_LABEL_KEYHELP_TITLE        0x93ff1404    // IDD_PROP_KEYHELP
+#define HIDC_LABEL_KEYHELP_ABOUT        0x93ff1410    // IDD_PROP_KEYHELP
 #define HIDC_LABEL_KEYHELP_KEYWORD      0x93ff1402    // IDD_PROP_KEYHELP
 #define HIDC_LABEL_KEYHELP_PRIOR        0x93ff1403    // IDD_PROP_KEYHELP
-#define HIDC_LABEL_KEYHELP_ABOUT        0x93ff1410    // IDD_PROP_KEYHELP
+#define HIDC_LABEL_KEYHELP_TITLE        0x93ff1404    // IDD_PROP_KEYHELP
 #define HIDC_LABEL_REGEX_COLOR          0x80db0581    // IDD_PROP_REGEX
 #define HIDC_LABEL_REGEX_KEYWORD        0x80db0582    // IDD_PROP_REGEX
 #define HIDC_LABEL_REGEX_VERSION        0x80db0589    // IDD_PROP_REGEX
@@ -396,7 +389,7 @@
 #define HIDC_STATIC_DIFF_SRC            0x93fb0594    // IDD_DIFF
 #define HIDC_STATIC_JRE32VER            0x806d0429    // IDD_FIND
 #define HIDC_STATIC_MSG                 0x809a046a    // IDD_INPUT1
-#define HIDC_TABWND_CAPTION             0x93f405bf    // IDD_PROP_WIN
+#define HIDC_TABWND_CAPTION             0x93f605bf    // IDD_PROP_TAB
 #define HIDC_TAB_FAVORITE               0x80e305b1    // IDD_FAVORITE
 #define HIDC_TREE1                      0x807a0474    // IDD_FUNCLIST
 #define HIDOK                           0x80730001    // IDD_ABOUT
Index: sakura_core/sakura_rc.rc
===================================================================
--- sakura_core/sakura_rc.rc	(revision 1065)
+++ sakura_core/sakura_rc.rc	(working copy)
@@ -116,7 +116,7 @@
             MENUITEM "-----dummy--------",          IDM_POPLAST2
         END
         MENUITEM SEPARATOR
-        MENUITEM "‚·‚×‚Ä•Â‚¶‚é(&Q)", F_WIN_CLOSEALL
+        MENUITEM "‚·‚×‚Ä•Â‚¶‚é(&Q)",            F_WIN_CLOSEALL
         MENUITEM "ƒTƒNƒ‰ƒGƒfƒBƒ^‚Ì‘S�I—¹(&X)",  F_EXITALL
     END
 END
@@ -928,8 +928,7 @@
     GROUPBOX        "ƒL�[ƒ��[ƒhƒwƒ‹ƒv",IDC_STATIC,3,123,264,33,WS_GROUP
     CONTROL         "ƒLƒƒƒŒƒbƒgˆÊ’u‚Ì’PŒê‚ðŽ«�‘ŒŸ�õ(&M)",
                     IDC_CHECK_CLICKKEYSEARCH,"Button",BS_AUTOCHECKBOX | 
-                    WS_TABSTOP,8,138,152,10,0,
-                    HIDC_CHECK_CLICKKEYSEARCH
+                    WS_TABSTOP,8,138,152,10
     PUSHBUTTON      "ƒtƒHƒ“ƒg(&F)...",IDC_BUTTON_KEYWORDHELPFONT,212,136,51,
                     14,0,0,HIDC_BUTTON_KEYWORDHELPFONT
     LTEXT           "DLL(&M)",IDC_STATIC,7,172,22,8
@@ -1288,7 +1287,7 @@
     DEFPUSHBUTTON   "•Â‚¶‚é(&C)",IDOK,300,170,50,14
 END
 
-IDD_PROP_WIN DIALOGEX 0, 0, 271, 225
+IDD_PROP_WIN DIALOGEX 0, 0, 271, 209
 STYLE DS_MODALFRAME | DS_3DLOOK | DS_CENTER | DS_CONTEXTHELP | WS_POPUP | 
     WS_CAPTION | WS_SYSMENU
 EXSTYLE WS_EX_CONTEXTHELP
@@ -1306,9 +1305,6 @@
     CONTROL         "ƒ^ƒuƒo�[•\Ž¦(&D)",IDC_CHECK_DispTabWnd,"Button",
                     BS_AUTOCHECKBOX | WS_TABSTOP,102,11,67,10,0,
                     HIDC_CHECK_DispTabWnd
-    CONTROL         "‚Ü‚Æ‚ß‚È‚¢(&N)",IDC_CHECK_DispTabWndMultiWin,"Button",
-                    BS_AUTOCHECKBOX | WS_TABSTOP,111,25,56,10,0,
-                    HIDC_CHECK_DispTabWndMultiWin
     CONTROL         "�…•½ƒXƒNƒ��[ƒ‹ƒo�[(&R)",IDC_CHECK_bScrollBarHorz,"Button",
                     BS_AUTOCHECKBOX | WS_TABSTOP,176,11,85,10,0,
                     HIDC_CHECK_bScrollBarHorz
@@ -1346,7 +1342,7 @@
     CONTROL         "�…•½ƒXƒNƒ��[ƒ‹‚Ì“¯Šú‚ð‚Æ‚é(&H)",
                     IDC_CHECK_SplitterWndHScroll,"Button",BS_AUTOCHECKBOX | 
                     WS_TABSTOP,8,139,107,10
-    GROUPBOX        "•ªŠ„ƒEƒBƒ“ƒhƒE",IDC_STATIC,3,114,145,39,WS_GROUP
+    GROUPBOX        "•ªŠ„ƒEƒBƒ“ƒhƒE",IDC_STATIC,3,114,264,39,WS_GROUP
     LTEXT           "ˆÊ’u",IDC_STATIC,159,82,19,10
     CONTROL         "�ã(&O)",IDC_RADIO_FUNCKEYWND_PLACE1,"Button",
                     BS_AUTORADIOBUTTON | WS_GROUP | WS_TABSTOP,183,82,30,10,
@@ -1361,31 +1357,11 @@
                     UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS,252,94,10,
                     12
     GROUPBOX        "ƒtƒ@ƒ“ƒNƒVƒ‡ƒ“ƒL�[",IDC_STATIC,154,70,113,39
-    CONTROL         "“™•�(&Q)",IDC_CHECK_SameTabWidth,"Button",
-                    BS_AUTOCHECKBOX | WS_GROUP | WS_TABSTOP,159,126,39,10,0,
-                    HIDC_CHECK_SameTabWidth
-    CONTROL         "ƒAƒCƒRƒ“•\Ž¦(&C)",IDC_CHECK_DispTabIcon,"Button",
-                    BS_AUTOCHECKBOX | WS_TABSTOP,200,126,67,10,0,
-                    HIDC_CHECK_DispTabIcon
-    CONTROL         "ƒ^ƒuˆê——ƒ\�[ƒg(&^)",IDC_CHECK_SortTabList,"Button",
-                    BS_AUTOCHECKBOX | WS_TABSTOP,159,140,62,10,0,
-                    HIDC_CHECK_SortTabList
-    GROUPBOX        "ƒ^ƒuƒo�[",IDC_STATIC,154,114,113,39,WS_GROUP
     LTEXT           "ƒAƒNƒeƒBƒuŽž(&1)",IDC_STATIC,7,171,45,8
     EDITTEXT        IDC_WINCAPTION_ACTIVE,60,168,201,14,ES_AUTOHSCROLL
     LTEXT           "”ñƒAƒNƒeƒBƒuŽž(&2)",IDC_STATIC,7,188,52,8
     EDITTEXT        IDC_WINCAPTION_INACTIVE,60,185,201,14,ES_AUTOHSCROLL
-    LTEXT           "ƒ^ƒu(&3)",IDC_STATIC,7,204,22,10
-    EDITTEXT        IDC_TABWND_CAPTION,60,202,201,14,ES_AUTOHSCROLL,0,
-                    HIDC_TABWND_CAPTION
-    GROUPBOX        "ƒ^ƒCƒgƒ‹ƒo�[",IDC_STATIC,3,157,264,63
-    CONTROL         "ƒXƒ^ƒCƒ‹-1",IDC_RADIO_nRulerType_0,"Button",
-                    BS_AUTORADIOBUTTON | NOT WS_VISIBLE | WS_GROUP,8,206,45,
-                    10
-    CONTROL         "ƒXƒ^ƒCƒ‹-2",IDC_RADIO_nRulerType_1,"Button",
-                    BS_AUTORADIOBUTTON | NOT WS_VISIBLE,54,206,47,10
-    GROUPBOX        "�š�š�š”ñŒöŠJƒeƒXƒg‹@”\—p�š�š�š",IDC_STATIC,5,197,257,22,
-                    NOT WS_VISIBLE | WS_GROUP
+    GROUPBOX        "ƒ^ƒCƒgƒ‹ƒo�[",IDC_STATIC,3,157,264,47
 END
 
 IDD_PROP_EDIT DIALOGEX 0, 0, 270, 213
@@ -1415,18 +1391,41 @@
                     WS_GROUP | WS_TABSTOP,8,128,100,10,0,
                     HIDC_CHECK_bNotOverWriteCRLF
     GROUPBOX        "�ã�‘‚«ƒ‚�[ƒh",IDC_STATIC,3,113,130,35,WS_GROUP
+    CONTROL         "ƒNƒŠƒbƒN‚Å&URL‚ð‘I‘ð‚·‚é",IDC_CHECK_bSelectClickedURL,
+                    "Button",BS_AUTOCHECKBOX | WS_TABSTOP,147,19,89,10,0,
+                    HIDC_CHECK_bSelectClickedURL
+    GROUPBOX        "ƒNƒŠƒbƒJƒuƒ‹URL",IDC_STATIC,138,7,125,35,WS_GROUP
 END
 
-IDD_PROP_URL DIALOGEX 0, 0, 270, 49
-STYLE DS_MODALFRAME | DS_3DLOOK | DS_CENTER | DS_CONTEXTHELP | WS_POPUP | 
-    WS_CAPTION | WS_SYSMENU
+IDD_PROP_TAB DIALOGEX 0, 0, 271, 123
+STYLE DS_SETFONT | DS_MODALFRAME | DS_3DLOOK | DS_CENTER | DS_CONTEXTHELP | 
+    WS_POPUP | WS_CAPTION | WS_SYSMENU
 EXSTYLE WS_EX_CONTEXTHELP
 FONT 9, "‚l‚r ‚oƒSƒVƒbƒN", 0, 0, 0x1
 BEGIN
-    CONTROL         "ƒNƒŠƒbƒN‚Å&URL‚ð‘I‘ð‚·‚é",IDC_CHECK_bSelectClickedURL,
-                    "Button",BS_AUTOCHECKBOX | WS_TABSTOP,8,18,89,10,0,
-                    HIDC_CHECK_bSelectClickedURL
-    GROUPBOX        "ƒNƒŠƒbƒJƒuƒ‹URL",-1,3,3,264,35,WS_GROUP
+    GROUPBOX        "ƒ^ƒu‚ÌŒ`�ó",IDC_STATIC,7,7,257,47,WS_GROUP
+    CONTROL         "“™•�(&Q)",IDC_CHECK_SameTabWidth,"Button",
+                    BS_AUTOCHECKBOX | WS_GROUP | WS_TABSTOP,15,19,39,10,0,
+                    HIDC_CHECK_SameTabWidth
+    CONTROL         "ƒAƒCƒRƒ“•\Ž¦(&C)",IDC_CHECK_DispTabIcon,"Button",
+                    BS_AUTOCHECKBOX | WS_TABSTOP,80,19,67,10,0,
+                    HIDC_CHECK_DispTabIcon
+    CONTROL         "ƒ^ƒuˆê——‚ðƒ\�[ƒg‚·‚é(&S)",IDC_CHECK_SortTabList,"Button",
+                    BS_AUTOCHECKBOX | WS_TABSTOP,176,19,80,10,0,
+                    HIDC_CHECK_SortTabList
+    GROUPBOX        "ƒ^ƒuƒ‚�[ƒhŽž‚Ì“®�ì",IDC_STATIC,7,60,257,53
+    CONTROL         "�ÅŒã‚Ìƒtƒ@ƒCƒ‹‚ð•Â‚¶‚½‚Æ‚«(–³‘è)•¶�‘‚ðŽc‚·(&R)",
+                    IDC_CHECK_RetainEmptyWindow,"Button",BS_AUTOCHECKBOX | 
+                    WS_TABSTOP,24,84,226,12
+    CONTROL         "ƒEƒBƒ“ƒhƒE‚Ì•Â‚¶‚éƒ{ƒ^ƒ“‚ÍŒ»�Ý‚Ìƒtƒ@ƒCƒ‹‚Ì‚Ý•Â‚¶‚é(&1)",
+                    IDC_CHECK_CloseOneWin,"Button",BS_AUTOCHECKBOX | 
+                    WS_TABSTOP,24,100,226,9
+    CONTROL         "ƒEƒBƒ“ƒhƒE‚ð‚P‚Â‚É‚Ü‚Æ‚ß‚é(&N)",
+                    IDC_CHECK_DispTabWndMultiWin,"Button",BS_AUTOCHECKBOX | 
+                    WS_TABSTOP,15,72,239,10,0,HIDC_CHECK_DispTabWndMultiWin
+    LTEXT           "ƒLƒƒƒvƒVƒ‡ƒ“(&3)",IDC_STATIC,14,37,46,10
+    EDITTEXT        IDC_TABWND_CAPTION,63,35,193,14,ES_AUTOHSCROLL,0,
+                    HIDC_TABWND_CAPTION
 END
 
 IDD_PROP_GREP DIALOGEX 0, 0, 271, 139
@@ -2333,7 +2332,7 @@
         LEFTMARGIN, 2
         RIGHTMARGIN, 269
         TOPMARGIN, 2
-        BOTTOMMARGIN, 222
+        BOTTOMMARGIN, 206
     END
 
     IDD_PROP_EDIT, DIALOG
@@ -2344,12 +2343,12 @@
         BOTTOMMARGIN, 206
     END
 
-    IDD_PROP_URL, DIALOG
+    IDD_PROP_TAB, DIALOG
     BEGIN
         LEFTMARGIN, 7
-        RIGHTMARGIN, 263
+        RIGHTMARGIN, 264
         TOPMARGIN, 7
-        BOTTOMMARGIN, 42
+        BOTTOMMARGIN, 116
     END
 
     IDD_PROP_GREP, DIALOG

Index: sakura_core/CPropCommon.h
===================================================================
--- sakura_core/CPropCommon.h	(revision 1065)
+++ sakura_core/CPropCommon.h	(working copy)
@@ -35,7 +35,7 @@
 #define ID_PAGENUM_FILE		3
 #define ID_PAGENUM_BACKUP	4
 #define ID_PAGENUM_FORMAT	5	//Oct. 25, 2000 JEPRO  1�¨ 5 ‚É•Ï�X
-#define ID_PAGENUM_URL		6
+#define ID_PAGENUM_TAB		6	//Feb. 11, 2007 genta URL‚Æ“ü‚êŠ·‚¦
 #define ID_PAGENUM_GREP		7
 #define ID_PAGENUM_KEYBOARD	8
 #define ID_PAGENUM_CUSTMENU	9	//Oct. 25, 2000 JEPRO 11�¨ 9 ‚É•Ï�X
@@ -241,13 +241,14 @@
 	int GetData_PROP_WIN( HWND );
 
 	//==============================================================
-	//!	ƒNƒŠƒbƒJƒuƒ‹URLƒy�[ƒW‚ÌDialog Procedure
-	static INT_PTR CALLBACK DlgProc_PROP_URL(
+	//!	ƒ^ƒu“®�ìƒy�[ƒW‚ÌDialog Procedure
+	static INT_PTR CALLBACK DlgProc_PROP_TAB(
 		HWND hwndDlg, UINT uMsg, WPARAM wParam, LPARAM lParam );
-	//! Message Handler for clickable URL page
-	INT_PTR DispatchEvent_PROP_URL( HWND, UINT, WPARAM, LPARAM );
-	void SetData_PROP_URL( HWND );
-	int GetData_PROP_URL( HWND );
+	//! Message Handler for TAB page
+	INT_PTR DispatchEvent_PROP_TAB( HWND, UINT, WPARAM, LPARAM );
+	void SetData_PROP_TAB( HWND );
+	int GetData_PROP_TAB( HWND );
+	void EnableTabPropInput(HWND hwndDlg);
 
 	//==============================================================
 	//!	•Ò�Wƒy�[ƒW‚ÌDialog Procedure